@@ -279,7 +279,7 @@ class PytconfConf:
         if os.path.isfile(file_name):
             with open(file_name, "rt") as json_file:
                 new_flags: Dict[str, str] = json.load(json_file)
-                assert type(flags) is dict
+                assert isinstance(flags, dict)
             for k, v in new_flags.items():
                 flags[k] = v
 
@@ -490,12 +490,18 @@ def get_pytconf():
     return _pytconf
 
 
-def config_arg_parse_and_launch(launch=True, args=None) -> None:
+def config_arg_parse_and_launch(
+    args=None,
+    launch=True,
+    do_exit=True,
+) -> None:
     """
     This is the real API
     """
     get_pytconf().config_arg_parse_and_launch(
-        launch=launch, args=args,
+        args=args,
+        launch=launch,
+        do_exit=do_exit,
     )
 
 
